@@ -4,12 +4,35 @@ import requests
 from urlparse import urlparse
 from functools import wraps
 
-from .things import Blob, ListBlob, Account, identify_class
+from .things import Blob, ListBlob, Account, identify_thing
 from .util import relative_url, pull_data_dict
 from .exceptions import NotLoggedIn, BadResponse, PostError, LoginFail
 from .const import DEFAULT_USER_AGENT, LOGIN_URL, POST_ERROR_PATTERN, API_PERIOD, SUBMIT_RESPONSE_LINK_PATTERN
 
 
+def _limit_rate(f, period=API_PERIOD):
+    @wraps(f)
+    def wrapper(self, *args, **kwargs):
+        if self._respect and self._last_request_time:
+            elapsed = time.time() - self._last_request_time
+            diff = period - elapsed
+            if diff > 0:
+                time.sleep(diff)
+        self._last_request_time = time.time()
+        return f(self, *args, **kwargs)
+    return wrapper
+
+
+def _login_required(f):
+    @wraps(f)
+    def wrapper(self, *args, **kwargs):
+        if self.logged_in:
+            return f(self, *args, **kwargs)
+        else:
+            raise NotLoggedIn()
+    return wrapper
+
+
 def _process_userlist(userlist):
     r = userlist.children
     items = []
@@ -32,7 +55,6 @@ class Reddit(object):
     :type respect: True or False
     """
     def __init__(self, username=None, password=None, user_agent=None, respect=True):
-        self._username = username
         self._modhash = None
         self._cookies = None
         self._respect = respect
@@ -49,27 +71,6 @@ class Reddit(object):
     def __repr__(self):
         return '<Reddit [{}]>'.format(self._username or '(not logged in)')
     
-    def _login_required(f):
-        @wraps(f)
-        def wrapper(self, *args, **kwargs):
-            if self.logged_in:
-                return f(self, *args, **kwargs)
-            else:
-                raise NotLoggedIn()
-        return wrapper
-    
-    def _limit_rate(f):
-        @wraps(f)
-        def wrapper(self, *args, **kwargs):
-            if self._respect and self._last_request_time:
-                elapsed = time.time() - self._last_request_time
-                diff = API_PERIOD - elapsed
-                if diff > 0:
-                    time.sleep(diff)
-            self._last_request_time = time.time()
-            return f(self, *args, **kwargs)
-        return wrapper
-    
     def _inject_request_kwargs(self, kwargs):
         if self._cookies:
             kwargs.setdefault('cookies', self._cookies)
@@ -88,7 +89,7 @@ class Reddit(object):
         
         def recur(v):
             if isinstance(v, dict):
-                klass = identify_class(v)
+                klass = identify_thing(v)
                 tmp = klass(self)
                 tmp._path = path
                 retval = helper(tmp, v if klass is Blob else v['data'])
@@ -168,14 +169,13 @@ class Reddit(object):
                 j = json.loads(r.content)
                 self._cookies = r.cookies
                 self._modhash = j['json']['data']['modhash']
+                self._username = username
                 return r
             except Exception:
                 raise LoginFail()
         else:
             raise BadResponse(r)
     
-    # START: Basic getting
-    
     def _limit_get(self, *args, **kwargs):
         limit = kwargs.pop('limit') if 'limit' in kwargs else None
         if limit is not None:
@@ -304,6 +304,18 @@ class Reddit(object):
         """
         return self._limit_get('user', user, 'submitted', limit=limit)
     
+    def moderators(self, sr):
+        """GETs moderators of subreddit ``sr``.  Returns :class:`things.ListBlob` object.
+        
+        **NOTE**: The :class:`things.Account` objects in the returned ListBlob *only* have ``id`` and ``name`` set.  This is because that's all reddit returns.  If you need full info on each moderator, you must individually GET them using :meth:`user` or :meth:`things.Account.about`.
+        
+        URL: ``http://www.reddit.com/r/<sr>/about/moderators/``
+        
+        :param sr: name of subreddit
+        """
+        userlist = self.get('r', sr, 'about', 'moderators')
+        return _process_userlist(userlist)
+    
     @_login_required
     def me(self):
         """Login required.  GETs info about logged in user.  Returns :class`things.Account` object.
@@ -326,22 +338,6 @@ class Reddit(object):
         """
         return self._limit_get('reddits', 'mine', limit=limit)
     
-    def moderators(self, sr):
-        """GETs moderators of subreddit ``sr``.  Returns :class:`things.ListBlob` object.
-        
-        **NOTE**: The :class:`things.Account` objects in the returned ListBlob *only* have ``id`` and ``name`` set.  This is because that's all reddit returns.  If you need full info on each moderator, you must individually GET them using :meth:`user` or :meth:`things.Account.about`.
-        
-        URL: ``http://www.reddit.com/r/<sr>/about/moderators/``
-        
-        :param sr: name of subreddit
-        """
-        userlist = self.get('r', sr, 'about', 'moderators')
-        return _process_userlist(userlist)
-    
-    # END: Basic getting
-    
-    # START: Logged-in user's basic actions
-    
     @_login_required
     def saved(self, limit=None):
         """Login required.  GETs logged in user's saved submissions.  Returns :class:`things.Listing` object.
@@ -495,6 +491,17 @@ class Reddit(object):
         """
         return self._submit(sr, title, 'self', text=text, follow=follow)
     
+    @_login_required
+    def delete(self, id_):
+        """Login required.  Send POST to delete an object.  Returns :class:`requests.Response` object.
+        
+        URL: ``http://www.reddit.com/api/delete/``
+        
+        :param sr: full id of object to delete   
+        """
+        data = dict(id=id_)
+        return self.post('api', 'delete', data=data)
+    
     @_login_required
     def save(self, id_):
         """Login required.  Sends POST to save a link.  Returns :class:`requests.Response` object.
@@ -676,21 +683,6 @@ class Reddit(object):
         data = dict(action='unsub', sr=sr)
         return self.post('api', 'subscribe', data=data)
     
-    @_login_required
-    def delete(self, id_):
-        """Login required.  Send POST to delete an object.  Returns :class:`requests.Response` object.
-        
-        URL: ``http://www.reddit.com/api/delete/``
-        
-        :param sr: full id of object to delete   
-        """
-        data = dict(id=id_)
-        return self.post('api', 'delete', data=data)
-    
-    # END: Logged-in user's basic actions
-    
-    # START: Logged-in user's messages and comments
-    
     @_login_required
     def inbox(self, limit=None):
         """Login required.  GETs logged in user's inbox. Returns :class:`things.Listing` object.
@@ -785,10 +777,6 @@ class Reddit(object):
         """
         return self._limit_get('user', self._username, 'hidden', limit=limit)
     
-    # END: Logged-in user's messages and comments
-    
-    # START: Mod actions
-    
     @_login_required
     def approve(self, id_):
         """Login required.  Sends POST to approve a submission. Returns :class:`things.Listing` object.
@@ -883,8 +871,6 @@ class Reddit(object):
         """
         userlist = self.get('r', sr, 'about', 'contributors')
         return _process_userlist(userlist)
-    
-    # END: Mod actions
 
 
 def connect(*args, **kwargs):
